==> klayout-0.14.tar.gz: klayout-0.14/testdata/ruby/layMenuTest.rb <==


require "test/unit"

class TestImpl < Test::Unit::TestCase

  def test_1

    app = RBA::Application.instance
    mw = app.main_window
    menu = mw.menu

    app.set_config( "ruler-templates", "" )

    def item_str( menu ) 
      def collect_children(space, menu, item)
        res = "#{space}#{item}\n"
        menu.items(item).each { |child| res += collect_children("  #{space}", menu, child) }
        return res;
      end
      res = ""
      menu.items("").each { |item| res += collect_children("", menu, item) }
      return res
    end

    # since the menu is somewhat dynamic, this is not really a good idea:
    if true
      assert_equal( item_str(menu), <<RESULT )
file_menu
  file_menu.open
  file_menu.open_same_panel
  file_menu.open_new_panel
  file_menu.close
  file_menu.clone
  file_menu.reload
  file_menu.save_group
  file_menu.save_as
  file_menu.setup_group
  file_menu.setup
  file_menu.misc_group
  file_menu.screenshot
  file_menu.layout_props
  file_menu.layer_group
  file_menu.load_layer_props
  file_menu.save_layer_props
  file_menu.exit_group
  file_menu.exit
edit_menu
  edit_menu.undo
  edit_menu.redo
  edit_menu.misc_group
  edit_menu.delete
  edit_menu.show_properties
  edit_menu.cpc_group
  edit_menu.copy
  edit_menu.cut
  edit_menu.paste
  edit_menu.modes_group
  edit_menu.mode_menu
    edit_menu.mode_menu.select
    edit_menu.mode_menu.move
    edit_menu.mode_menu.ruler
  edit_menu.select_menu
    edit_menu.select_menu.pi_enable_1
    edit_menu.select_menu.pi_enable_2
    edit_menu.select_menu.pi_enable_3
    edit_menu.select_menu.pi_enable_4
    edit_menu.select_menu.pi_enable_5
    edit_menu.select_menu.pi_enable_6
  edit_menu.cancel_group
  edit_menu.cancel
  edit_menu.rulers_group
  edit_menu.clear_all_rulers
  edit_menu.configure_rulers
bookmark_menu
  bookmark_menu.goto_bookmark_menu
  bookmark_menu.bookmark_view
  bookmark_menu.bookmark_mgm_group
  bookmark_menu.manage_bookmarks
  bookmark_menu.load_bookmarks
  bookmark_menu.save_bookmarks
zoom_menu
  zoom_menu.max_hier
  zoom_menu.max_hier_0
  zoom_menu.max_hier_1
  zoom_menu.inc_max_hier
  zoom_menu.dec_max_hier
  zoom_menu.zoom_group
  zoom_menu.zoom_fit
  zoom_menu.zoom_in
  zoom_menu.zoom_out
  zoom_menu.pan_group
  zoom_menu.pan_up
  zoom_menu.pan_down
  zoom_menu.pan_left
  zoom_menu.pan_right
  zoom_menu.redraw_group
  zoom_menu.redraw
  zoom_menu.state_group
  zoom_menu.last_display_state
  zoom_menu.next_display_state
  zoom_menu.select_group
  zoom_menu.select_cell
  zoom_menu.select_current_cell
  zoom_menu.goto_position
  zoom_menu.edt
  zoom_menu.descend
  zoom_menu.ascend
tools_menu
  tools_menu.console
  tools_menu.tools_group
  tools_menu.browse_shapes
  tools_menu.browse_instances
help_group
help_menu
  help_menu.about
@toolbar
  @toolbar.select
  @toolbar.move
  @toolbar.ruler
@lcp_context_menu
  @lcp_context_menu.select_all
  @lcp_context_menu.visibility_group
  @lcp_context_menu.hide
  @lcp_context_menu.show
  @lcp_context_menu.rename
  @lcp_context_menu.source_group
  @lcp_context_menu.select_source
  @lcp_context_menu.sort_group
  @lcp_context_menu.sort_menu
    @lcp_context_menu.sort_menu.sort_ild
    @lcp_context_menu.sort_menu.sort_idl
    @lcp_context_menu.sort_menu.sort_ldi
    @lcp_context_menu.sort_menu.sort_dli
    @lcp_context_menu.sort_menu.sort_name
  @lcp_context_menu.view_group
  @lcp_context_menu.del
  @lcp_context_menu.insert
  @lcp_context_menu.add_others
  @lcp_context_menu.clean_up
  @lcp_context_menu.grouping_group
  @lcp_context_menu.group
  @lcp_context_menu.ungroup
  @lcp_context_menu.regroup_menu
    @lcp_context_menu.regroup_menu.grp_i
    @lcp_context_menu.regroup_menu.grp_d
    @lcp_context_menu.regroup_menu.grp_l
    @lcp_context_menu.regroup_menu.flatten
@hcp_context_menu
  @hcp_context_menu.show_as_top
  @hcp_context_menu.visibility_group
  @hcp_context_menu.hide_cell
  @hcp_context_menu.show_cell
  @hcp_context_menu.show_all
  @hcp_context_menu.utils_group
  @hcp_context_menu.open_current
  @hcp_context_menu.file_group
  @hcp_context_menu.save_as
RESULT
    end

    menu.delete_item("@hcp_context_menu")
    menu.delete_item("@lcp_context_menu")
    menu.delete_item("help_group")
    menu.delete_item("tools_menu")
    menu.delete_item("edit_menu")
    menu.delete_item("zoom_menu")

    $a1 = RBA::Action::new
    $a1.title = "New title"
    $a1.icon_text = "X"
    $a1.shortcut = "Shift+Ctrl+F7"
    menu.insert_menu( "end", "my_menu", "My menu" )
    menu.insert_item( "my_menu.end", "new_item", $a1 )
    menu.insert_item( "file_menu.begin", "new_item_1", $a1 )
    menu.insert_separator( "file_menu.#3", "sep" )
    menu.insert_item( "file_menu.#3", "new_item_2", $a1 )

    assert_equal( menu.action("my_menu").title, "My menu" )

    assert_equal( item_str(menu), <<RESULT )
file_menu
  file_menu.new_item_1
  file_menu.open
  file_menu.open_same_panel
  file_menu.new_item_2
  file_menu.sep
  file_menu.open_new_panel
  file_menu.close
  file_menu.clone
  file_menu.reload
  file_menu.save_group
  file_menu.save_as
  file_menu.setup_group
  file_menu.setup
  file_menu.misc_group
  file_menu.screenshot
  file_menu.layout_props
  file_menu.layer_group
  file_menu.load_layer_props
  file_menu.save_layer_props
  file_menu.exit_group
  file_menu.exit
bookmark_menu
  bookmark_menu.goto_bookmark_menu
  bookmark_menu.bookmark_view
  bookmark_menu.bookmark_mgm_group
  bookmark_menu.manage_bookmarks
  bookmark_menu.load_bookmarks
  bookmark_menu.save_bookmarks
help_menu
  help_menu.about
@toolbar
  @toolbar.select
  @toolbar.move
  @toolbar.ruler
my_menu
  my_menu.new_item
RESULT

    assert_equal( menu.action( "file_menu.#0" ).title, "New title" )
    assert_equal( menu.action( "file_menu.#0" ).shortcut, "Ctrl+Shift+F7" )
    assert_equal( menu.action( "file_menu.#3" ).icon_text, "X" )
    assert_equal( menu.action( "my_menu.new_item" ).is_visible?, true )
    assert_equal( menu.action( "file_menu.#3" ).is_checked?, false )
    assert_equal( menu.action( "my_menu.new_item" ).is_enabled?, true )

    $a1.visible = false
    assert_equal( menu.action( "my_menu.new_item" ).is_visible?, false )
    assert_equal( menu.action( "my_menu.new_item" ).is_checked?, false )
    assert_equal( menu.action( "my_menu.new_item" ).is_enabled?, true )

    $a1.checked = true
    assert_equal( menu.action( "file_menu.#3" ).is_visible?, false )
    assert_equal( menu.action( "file_menu.#3" ).is_checked?, false )
    assert_equal( menu.action( "file_menu.#3" ).is_checkable?, false )
    assert_equal( menu.action( "file_menu.#3" ).is_enabled?, true )

    $a1.checkable = true;
    assert_equal( menu.action( "my_menu.new_item" ).is_visible?, false )
    assert_equal( menu.action( "my_menu.new_item" ).is_checked?, false )
    assert_equal( menu.action( "my_menu.new_item" ).is_checkable?, true )
    assert_equal( menu.action( "my_menu.new_item" ).is_enabled?, true )
    $a1.checked = true
    assert_equal( menu.action( "file_menu.#0" ).is_checked?, true )

    $a1.enabled = false
    assert_equal( menu.action( "my_menu.new_item" ).is_visible?, false )
    assert_equal( menu.action( "my_menu.new_item" ).is_checked?, true )
    assert_equal( menu.action( "my_menu.new_item" ).is_enabled?, false )

  end

  class MenuHandler < RBA::Action
    def initialize( t, k, &action ) 
      self.title = t
      self.shortcut = k
      @action = action
    end
    def triggered 
      @action.call( self ) 
    end
  private
    @action
  end

  def test_2

    app = RBA::Application.instance
    mw = app.main_window
    menu = mw.menu

    triggered = false

    $f7_handler = MenuHandler.new( "Ruby Test", "F7" ) {
      triggered = true
    }

    menu.insert_item("file_menu.begin", "new_item", $f7_handler)
    menu.action("file_menu.#0").trigger

    assert_equal( triggered, true )

    triggered = false

    menu.insert_item("help_menu.end", "new_item_copy", menu.action("file_menu.#0") )

    menu.action("help_menu.new_item_copy").trigger

    assert_equal( triggered, true )

  end

end


# In the test environment, we cannot make sure that we destroy the ruby interpreter before the RBA
# environment is shut down. Therefore we must release all RBA objects by explicitly calling the GC
# and start the test suite manually.

require 'test/unit/ui/console/testrunner'
Test::Unit::UI::Console::TestRunner.run(TestImpl)

GC.start

# To test if the application is still functional after the menu has been stripped and 
# modified, enable this:
# RBA::Application.instance.exec

==> klayout-0.15.tar.gz: klayout-0.15/testdata/ruby/layMenuTest.rb <==


require "test/unit"

class TestImpl < Test::Unit::TestCase

  def test_1

    app = RBA::Application.instance
    mw = app.main_window
    menu = mw.menu

    app.set_config( "ruler-templates", "" )

    def item_str( menu ) 
      def collect_children(space, menu, item)
        res = "#{space}#{item}\n"
        menu.items(item).each { |child| res += collect_children("  #{space}", menu, child) }
        return res;
      end
      res = ""
      menu.items("").each { |item| res += collect_children("", menu, item) }
      return res
    end

    # since the menu is somewhat dynamic, this is not really a good idea
    # (in addition, the menu depends on the mode - editable or not)
    if false
      assert_equal( item_str(menu), <<RESULT )
file_menu
...
  @hcp_context_menu.save_as
RESULT
    end

    menu.delete_item("@toolbar.partial")
    menu.delete_item("@toolbar.instance")
    menu.delete_item("@toolbar.polygon")
    menu.delete_item("@toolbar.box")
    menu.delete_item("@toolbar.path")
    menu.delete_item("@toolbar.text")
    menu.delete_item("@hcp_context_menu")
    menu.delete_item("@lcp_context_menu")
    menu.delete_item("help_group")
    menu.delete_item("tools_menu")
    menu.delete_item("edit_menu")
    menu.delete_item("zoom_menu")

    $a1 = RBA::Action::new
    $a1.title = "New title"
    $a1.icon_text = "X"
    $a1.shortcut = "Shift+Ctrl+F7"
    menu.insert_menu( "end", "my_menu", "My menu" )
    menu.insert_item( "my_menu.end", "new_item", $a1 )
    menu.insert_item( "file_menu.begin", "new_item_1", $a1 )
    menu.insert_separator( "file_menu.#3", "sep" )
    menu.insert_item( "file_menu.#3", "new_item_2", $a1 )

    assert_equal( menu.action("my_menu").title, "My menu" )

    assert_equal( item_str(menu), <<RESULT )
file_menu
  file_menu.new_item_1
  file_menu.new_layout
  file_menu.post_new_group
  file_menu.new_item_2
  file_menu.sep
  file_menu.open
  file_menu.open_same_panel
  file_menu.open_new_panel
  file_menu.close
  file_menu.clone
  file_menu.reload
  file_menu.save_group
  file_menu.save
  file_menu.save_as
  file_menu.setup_group
  file_menu.setup
  file_menu.misc_group
  file_menu.screenshot
  file_menu.layout_props
  file_menu.layer_group
  file_menu.load_layer_props
  file_menu.save_layer_props
  file_menu.exit_group
  file_menu.exit
bookmark_menu
  bookmark_menu.goto_bookmark_menu
  bookmark_menu.bookmark_view
  bookmark_menu.bookmark_mgm_group
  bookmark_menu.manage_bookmarks
  bookmark_menu.load_bookmarks
  bookmark_menu.save_bookmarks
help_menu
  help_menu.about
@toolbar
  @toolbar.select
  @toolbar.move
  @toolbar.ruler
my_menu
  my_menu.new_item
RESULT

    assert_equal( menu.action( "file_menu.#0" ).title, "New title" )
    assert_equal( menu.action( "file_menu.#0" ).shortcut, "Ctrl+Shift+F7" )
    assert_equal( menu.action( "file_menu.#3" ).icon_text, "X" )
    assert_equal( menu.action( "my_menu.new_item" ).is_visible?, true )
    assert_equal( menu.action( "file_menu.#3" ).is_checked?, false )
    assert_equal( menu.action( "my_menu.new_item" ).is_enabled?, true )

    $a1.visible = false
    assert_equal( menu.action( "my_menu.new_item" ).is_visible?, false )
    assert_equal( menu.action( "my_menu.new_item" ).is_checked?, false )
    assert_equal( menu.action( "my_menu.new_item" ).is_enabled?, true )

    $a1.checked = true
    assert_equal( menu.action( "file_menu.#3" ).is_visible?, false )
    assert_equal( menu.action( "file_menu.#3" ).is_checked?, false )
    assert_equal( menu.action( "file_menu.#3" ).is_checkable?, false )
    assert_equal( menu.action( "file_menu.#3" ).is_enabled?, true )

    $a1.checkable = true;
    assert_equal( menu.action( "my_menu.new_item" ).is_visible?, false )
    assert_equal( menu.action( "my_menu.new_item" ).is_checked?, false )
    assert_equal( menu.action( "my_menu.new_item" ).is_checkable?, true )
    assert_equal( menu.action( "my_menu.new_item" ).is_enabled?, true )
    $a1.checked = true
    assert_equal( menu.action( "file_menu.#0" ).is_checked?, true )

    $a1.enabled = false
    assert_equal( menu.action( "my_menu.new_item" ).is_visible?, false )
    assert_equal( menu.action( "my_menu.new_item" ).is_checked?, true )
    assert_equal( menu.action( "my_menu.new_item" ).is_enabled?, false )

  end

  class MenuHandler < RBA::Action
    def initialize( t, k, &action ) 
      self.title = t
      self.shortcut = k
      @action = action
    end
    def triggered 
      @action.call( self ) 
    end
  private
    @action
  end

  def test_2

    app = RBA::Application.instance
    mw = app.main_window
    menu = mw.menu

    triggered = false

    $f7_handler = MenuHandler.new( "Ruby Test", "F7" ) {
      triggered = true
    }

    menu.insert_item("file_menu.begin", "new_item", $f7_handler)
    menu.action("file_menu.#0").trigger

    assert_equal( triggered, true )

    triggered = false

    menu.insert_item("help_menu.end", "new_item_copy", menu.action("file_menu.#0") )

    menu.action("help_menu.new_item_copy").trigger

    assert_equal( triggered, true )

  end

end


# In the test environment, we cannot make sure that we destroy the ruby interpreter before the RBA
# environment is shut down. Therefore we must release all RBA objects by explicitly calling the GC
# and start the test suite manually.

require 'test/unit/ui/console/testrunner'
Test::Unit::UI::Console::TestRunner.run(TestImpl)

GC.start

# To test if the application is still functional after the menu has been stripped and 
# modified, enable this:
# RBA::Application.instance.exec
